ReadThroughCache

Struct ReadThroughCache 

pub struct ReadThroughCache<B, S, M, K, V, L>{ /* private fields */ }
A cache wrapper that automatically loads data on miss

Implementations

Source

impl<B, S, M, K, V, L> ReadThroughCache<B, S, M, K, V, L>
where B: CacheBackend + DependencyBackend, S: Serializer, M: CacheMetrics, K: CacheKey + Clone + Send + Sync + 'static, V: Serialize + DeserializeOwned + Send + Sync + Clone + 'static, L: Loader<K, V>,

pub fn new( manager: CacheManager<B, S, M>, loader: L, options: CacheOptions, ) -> Self

Create a new ReadThroughCache

pub async fn get(&self, key: K) -> Result<Option<V>>

Get value from cache, or load it automatically if missing

pub async fn refresh(&self, key: K) -> Result<()>

Force refresh a key using the loader