pub trait CacheKey: Send + Sync {
// Required method
fn cache_key(&self) -> String;
// Provided methods
fn namespace(&self) -> Option<&str> { ... }
fn full_key(&self) -> String { ... }
}Expand description
Trait for types that can be used as cache keys
Implement this trait to use custom types as cache keys.